@@ -199,6 +199,9 @@ class Aggregator(Actor):
         Does not do anything if `ifra.node.Node` *model* is None
         """
         model = self.model
+        # Aggregated model's criterion and coverage are meaningless
+        model._coverage = None
+        model.criterion = None
 
         iteration = 0
         name = self.aggregator_configs.aggregated_model_path.stem
@@ -208,6 +211,8 @@ class Aggregator(Actor):
             path = self.aggregator_configs.aggregated_model_path.parent / f"{name}_{iteration}.csv"
 
         path = path.with_suffix(".csv")
+        if not path.parent.isdir():
+            path.parent.mkdir(parents=True)
         model.save(path)
         model.save(self.aggregator_configs.aggregated_model_path)
         logger.info(f"Saved aggregated model in '{self.aggregator_configs.aggregated_model_path}'")
@@ -234,7 +239,6 @@ class Aggregator(Actor):
         sleeptime: Union[int, float]
             How many seconds between each checks for new nodes models. Default value = 5.
         """
-        t = time()
         updated_nodes = []
         iterations = 0
 
@@ -244,11 +248,15 @@ class Aggregator(Actor):
             "Starting aggregator. Monitoring changes in nodes' models directories"
             f" {self.aggregator_configs.node_models_path}."
         )
+        started = False  # To force at least one loop of the while to trigger
 
-        while time() - t < timeout or timeout <= 0:
-
+        t = time()
+        while time() - t < timeout or timeout <= 0 or started is False:
+            started = True
             new_models = False
             new_nodes = 0
+            if not self.aggregator_configs.node_models_path.isdir():
+                self.aggregator_configs.node_models_path.mkdir(parents=True)
             for path in self.aggregator_configs.node_models_path.glob("model_main_*.csv"):
                 if path in NodeGate.paths:
                     # Already found this node in a previous check
