@@ -12,7 +12,7 @@ logger = logging.getLogger(__name__)
 def get_lock(path: TransparentPath, timeout: int = 5, exists: str = "wait") -> TransparentPath:
     lockfile = path.append(".lock")
     if not lockfile.parent.is_dir():
-        lockfile.mkdir(parents=True)
+        lockfile.parent.mkdir(parents=True)
         lockfile.touch()
         return lockfile
 
@@ -109,6 +109,13 @@ class Emitter:
         lockfile.rm(absent="ignore")
         self.reset_messages()
 
+    def __getstate__(self):
+        return self.__dict__
+
+    def __setstate__(self, d: dict):
+        for item in d:
+            setattr(self, item, d[item])
+
     def __getattr__(self, item):
         if item == "messages":
             raise ValueError("NodeMessenger object's 'messages' not set")
@@ -224,6 +231,13 @@ class Receiver:
         self.new = True
         self.get_latest_messages(wait)
 
+    def __getstate__(self):
+        return self.__dict__
+
+    def __setstate__(self, d: dict):
+        for item in d:
+            setattr(self, item, d[item])
+
     def __getattr__(self, item):
         if item == "messages":
             raise ValueError("Messenger object's 'messages' not set")
